# PACKAGES
require(ggplot2)
require(dplyr) 
require(broom)
require(forcats)
require(here)
here <- here::here

# LOAD DATA
data <- read.csv(here('raw_data', 'exp1.csv'), header = T)

#### DATA CLEANING ####
data$expCode <- factor(data$expCode, levels = c("assurance_v1", "PD_t_v1", "ass_by_unt_v1", "PD_unt_v1"))
data$matrix <- factor(data$matrix, levels = c("Ass", "PD"))
data$gender <- factor(data$gender, labels = c("male", "female")) # 0 = male, 1 = female
data$trustFaces <- factor(data$trustFaces, labels = c("untrust", "trust")) # 0 = untrustworthy cue face, 1 = trustworthy cue face
data$ethnicity <- factor(data$ethnicity) # 1 = Hispanic/Latino, 2 = White/Caucasian, 3 = Black/African American, 4 = Pacific Islander, 5 = Asian, 6 = Native American, 7 = Two or more races, 8 = Other
data$education <- factor(data$education, ordered = TRUE) # 0 = none, 1 = primary, 2 = some high school, 3   = completed high school, 4 = some university, 5 = bachelor's, 6 = postgrad
data$economics <- factor(data$economics, labels = c("no", "yes")) # 0 = no, 1 = yes
# Note that a straight gaze condition was also included in this experiment, where the cue face did not shift its gaze but this was not analysed for the paper.
data$gazeCon <- factor(data$gazeCon, labels = c("hare", "straight", "stag")) # -1 = gaze at hare, 0 = gaze straight, 1 = gaze at stag
data$stagSide <- factor(data$stagSide, labels = c("left", "right")) # 0 = stag on left, 1 = stag on right
data$faceID <- factor(data$faceID)
data$choice <- factor(data$choice, labels = c("hare", "stag")) # 0 = hare, 1 = stag
data$choiceCongruent <- factor(data$choiceCongruent, labels = c("no", "yes", "straight")) # 0 = choice not congruent with gaze cue, 1 = choice congruent with gaze cue, 2 = straight gaze therefore congruence not applicable
data$choiceSide <- factor(data$choiceSide, labels = c("left", "right")) # 0 = chose animal on left, 1 = chose animal on right
data$reasonForExp <- factor(data$reasonForExp)
# Reasons were as follows (note that order of presentation was randomised):
# 0 = To investigate whether the gaze direction of the computer-generated faces would affect which animal people chose to hunt.
# 1 = To investigate whether self-identified ethnicity affects trustworthiness ratings.
# 2 = To investigate hidden racial biases.
# 3 = To determine people\'s aversion to risk taking.
# 4 = Don\'t know / Some other purpose.
data$reasonCorrect <- factor(data$reasonCorrect, labels = c("wrong", "correct")) # 1 = participant identified the correct reason
# Participants were asked to enter their age and ethnicity again at the end of the experiment to check for nuisance responding
data$check <- factor(data$check, labels = c("fail", "pass")) # 1 = age and ethnicity match, 0 = they don't match
data$quiz.Cat<-cut(data$quizAttempts, c(0, 1, 11), c("One", "Multiple"))
data <- mutate(data, choiceBin = ifelse(choice == 'stag', 1, 0))

#### SAMPLE DEMOGRAPHICS ####
#take just one row from each subject in demos df to give us demos_summary df
#something we can calculate summary statistics from
c <- 1:nrow(data)
demos <- data[c%%6==1, ]
# age
mean(demos$age)
sd(demos$age)
# gender
table(demos$gender)
# education
# 0 = none, 1 = primary, 2 = some high school, 3   = completed high school, 4 = some university, 
# 5 = bachelor's, 6 = postgrad
table(demos$education)
# economics
table(demos$economics)
# quiz attempts
table(demos$quizAttempts)

#Save data
saveRDS(data, file = here('clean_data', 'exp1.rds'))





