require(dplyr)
require(ggplot2)
require(forcats)
require(here)
require(ggpubr)

# Load data
exp1 <- readRDS(file = here('clean_data', 'exp1.rds'))
exp2ab <- readRDS(file = here('clean_data', 'exp2ab.rds'))
exp2c <- readRDS(file = here('clean_data', 'exp2c.rds'))

# set reference levels and clean data
# exp 1
exp1$gazeCon <- factor(exp1$gazeCon, levels = c("hare", "stag"))
exp1$matrix <- factor(exp1$matrix, levels = c("PD", "Ass"))
exp1$trustFaces <- factor(exp1$trustFaces, levels = c("untrust", "trust"))
# Remove the straight gaze condition as we are not analysing it
exp1 <- filter(exp1, gazeCon != 'straight')

# exp 2ab
exp2ab$gazeCon <- factor(exp2ab$gazeCon, levels = c("hare", "stag"))
exp2ab$matrix <- factor(exp2ab$matrix, levels = c("PD", "Ass"))
exp2ab$trustFaces <- factor(exp2ab$trustFaces, levels = c("untrust", "trust"))
exp2ab$gazeMeanCheck <- factor(exp2ab$gazeMeanCheck, levels = c("no", "yes"))

exp2a <- filter(exp2ab, gazeMeanCheck == 'yes')
exp2a <- filter(exp2a, gazeCon != 'straight')

exp2b <- filter(exp2ab, gazeMeanCheck == 'no')
exp2b <- filter(exp2b, gazeCon != 'straight')

# exp 2c
exp2c$gazeCon <- factor(exp2c$gazeCon, levels = c("hare", "stag"))
exp2c$matrix <- factor(exp2c$matrix, levels = c("PD", "Ass"))
exp2c$trustFaces <- factor(exp2c$trustFaces, levels = c("untrust", "trust"))


# load functions to make plots
source(here('plotting', 'plot_funcs.R'))

# Set labels for plots
facet_labels <- as_labeller(c(`no` = 'No', `yes` = 'Yes', `Ass` = 'AG', `PD` = 'PD',
                              `meaningless` = 'Meaningless', `meaningful` = 'Meaningful',
                              `loadBig` = 'Cog load', `thinkPrompt` = 'Reflection prompt'))

#### exp 1 ####
exp1.coopRates <- coopRates.func(data = exp1)

exp1.plot <- plot.coop.func(plotData = exp1.coopRates, title = 'Experiment 1', facetVars = c('matrix'))

exp1.plot

#### exp 2a ####
exp2a.coopRates <- coopRates.func(data = exp2a)

exp2a.plot <- plot.coop.func(plotData = exp2a.coopRates, title = 'Exp 2a', facetVars = c('matrix'))

exp2a.plot

#### exp 2b ####
exp2b.coopRates <- coopRates.func(data = exp2b)

exp2b.plot <- plot.coop.func(plotData = exp2b.coopRates, title = 'Exp 2b', facetVars = c('matrix'))

exp2b.plot

#### exp 2c ####
exp2c.coopRates <- coopRates.func(data = exp2c)

exp2c.plot <- plot.coop.func(plotData = exp2c.coopRates, title = 'Exp 2c', facetVars = c('matrix'))

exp2c.plot

#### plot all experiments ####
plotAll <- ggarrange(exp1.plot, exp2a.plot, exp2b.plot, exp2c.plot, nrow = 2, ncol = 2, align = "hv")
plotAll

