# This function generates cooperation rates for each experiment and orders the conditions so that the plots
# display correctly (this is the reason for the call to 'arrange')
# The ... is used when there is an additional variable beyond matrix, gazeCon and trustFaces (ie
# for experiment 2 it will be gazeMeanCheck (passed as expression, not quoted) and for exp 4
# it will be load.

coopRates.func <- function(data, ...) {
  
  coopRates <- data %>% 
    group_by(matrix, ..., gazeCon, trustFaces) %>% 
    summarise(nCoop = sum(choice == 'stag'), nTotal = n(), coopPerc = (nCoop/nTotal)*100,
              CIlo = binom.test(x = nCoop, n = nTotal)$conf.int[1]*100, 
              CIhi = binom.test(x = nCoop, n = nTotal)$conf.int[2]*100) %>%
    as.data.frame()
  
  coopRates <- arrange(coopRates, matrix, ..., gazeCon, trustFaces)
  
  return(coopRates)
  
}

# this function plots the coopRates data (passed using the plotData argument). 
# title is a string passed to ggtitle. 
# facetVars is a vector of strings passed to facet_wrap. for exp1 it is just c('matrix') - 
# for exps 2 and 4 'gazeMeanCheck' and 'load' respectively are added to the string.

plot.coop.func <- function(plotData, title, facetVars) {
  
  # set up order so that columns display next to the correct label
  
  if (nrow(plotData) == 8) {
    order <- rep(c(seq(1,4,1)), times = 2)
    plotData$order <- as.factor(order)
  } else {
    order <- rep(c(seq(1,4,1)), times = 4)
    plotData$order <- as.factor(order)
  }
  
  plot <- ggplot(data = plotData, aes(x = interaction(gazeCon,trustFaces), y = coopPerc)) + 
    aes(x = fct_inorder(order)) +
    geom_col() +
    geom_errorbar(aes(ymin = CIlo, ymax = CIhi), width = .2) +
    scale_x_discrete(labels = c('Hare/U','Hare/T', 'Stag/U', 'Stag/T')) +
    facet_wrap(facetVars, labeller = facet_labels) +
    ggtitle(title) +
    scale_y_continuous(limits = c(0, 110), breaks = seq(0,100,10)) +
    geom_label(data = plotData, aes(label = round(coopPerc, 1)), nudge_y = 17, size = 2.5, label.padding = unit(0.15, 'lines')) + 
    xlab('Condition') +
    ylab('Cooperation rate (%)') +
    theme_classic() +
    theme(text = element_text(size=14),
          axis.text.x = element_text(angle = 45, hjust = 1))
  
  return(plot)
  
}



